# uas_standards

This library primarily provides data types and tools for working with standards related to uncrewed aircraft systems (UAS).

## Autogeneration

To regenerate autogenerated code:

* Update submodule reference to point to updated interface in [interfaces](./interfaces)
* From this root repo folder, `make apis`
* If necessary, `sudo chown -R $(id -un):$(id -gn) .` to change ownership of files if Docker created any with root permissions
